
## CATO-CLI - query.site.cloudInterconnectPhysicalConnectionId:
[Click here](https://api.catonetworks.com/documentation/#query-cloudInterconnectPhysicalConnectionId) for documentation on this operation.

### Usage for query.site.cloudInterconnectPhysicalConnectionId:

`catocli query site cloudInterconnectPhysicalConnectionId -h`

`catocli query site cloudInterconnectPhysicalConnectionId <json>`

`catocli query site cloudInterconnectPhysicalConnectionId "$(cat < cloudInterconnectPhysicalConnectionId.json)"`

`catocli query site cloudInterconnectPhysicalConnectionId '{"cloudInterconnectPhysicalConnectionIdInput": {"haRole": {"haRole": "enum(HaRole)"}, "siteRefInput": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}}'`

#### Operation Arguments for query.site.cloudInterconnectPhysicalConnectionId ####
`accountId` [ID] - (required) N/A 
`cloudInterconnectPhysicalConnectionIdInput` [CloudInterconnectPhysicalConnectionIdInput] - (required) N/A 
